#
# See the file "LICENSE" for the full license governing this code.
#
#
# Find all iib binaries and check the version for it
# return it as a hash.
#
Facter.add(:iib_full_versions) do
  iib_executables = []
  Dir.glob('/opt/**{/*/*iib-*,/*ace-*}/{iib,ace}').each do |path|
    # rubocop: disable Style/RegexpLiteral
    iib_executables << path[0..-5] if path.to_s =~ /.*\/iib-[\d.]+\/iib$|.*\/ace-[\d.]+\/ace$/
    # rubocop: enable Style/RegexpLiteral
  end
  setcode do
    versions = iib_executables.collect do |path|
      case path
      when /iib/
        info = Facter::Core::Execution.exec("#{path}/iib version")
      when /ace/
        info = Facter::Core::Execution.exec("#{path}/ace version")
      else
        raise 'Internal error getting IIB version.'
      end
      begin
        version = info.scan(/Version:\s*'(.*)'/)[0][0]
        build   = info.scan(/Build Number:\s*'(.*)'/)[0][0]
        Puppet.debug "Found IIB version #{version}=#{build} at #{path}."
      rescue NoMethodError
        #
        # When the iib version command returns somthing odd
        # we don't want any nil errors but want to return that the version
        # and build are unreadable.
        #
        version = 'unreadable'
        build   = 'unreadable'
      end
      [path, "#{version}-#{build}"]
    end
    Hash[versions]
  end
end
